Digimat MBIO - Éditeur de Zones

//
Digimat MBIO Zone Editor
`/`

## Sélectionner une variable MBIO

Clé (Key) | Valeur Actuelle | Description | Tag | Zone
--- | --- | --- | --- | ---

0 valeurs trouvées Mise à jour auto 5s
Modes
Outils

## Propriétés

Nom du Plan
Traitement Image
Négatif
Transp.
Rognage (px)
Transparence
Orientation
Nom de la zone
Variable MBIO
Label (Optionnel)

Entrez la clé API.

Sélection multiple.
Init...
F6: Edit F7: View PgUp/Dn: Plans